@@ -4,6 +4,27 @@
 //	Copyright (c) 2011 Samuel G. D. Williams. <http://www.oriontransfer.co.nz>
 //	See <jquery.syntax.js> for licensing details.
 
+Syntax.lib.xmlEntity = {pattern: /&\w+;/g, klass: 'entity'};
+Syntax.lib.xmlPercentEscape = {pattern: /(%[0-9a-f]{2})/gi, klass: 'percent-escape', only: ['string']};
+
+Syntax.register('xml-tag', function(brush) {
+	brush.push({
+		pattern: /<\/?((?:[^:\s>]+:)?)([^\s>]+)(\s[^>]*)?\/?>/g,
+		matches: Syntax.extractMatches({klass: 'namespace'}, {klass: 'tag-name'})
+	});
+	
+	brush.push({
+		pattern: /([^=\s]+)=(".*?"|'.*?'|[^\s>]+)/g,
+		matches: Syntax.extractMatches({klass: 'attribute', only: ['tag']}, {klass: 'string', only: ['tag']})
+	});
+	
+	brush.push(Syntax.lib.xmlEntity);
+	brush.push(Syntax.lib.xmlPercentEscape);
+	
+	brush.push(Syntax.lib.singleQuotedString);
+	brush.push(Syntax.lib.doubleQuotedString);
+});
+
 Syntax.register('xml', function(brush) {
 	brush.push({
 		pattern: /(<!(\[CDATA\[)([\s\S]*?)(\]\])>)/gm,
@@ -17,36 +38,13 @@ Syntax.register('xml', function(brush) {
 	
 	brush.push(Syntax.lib.xmlComment);
 	
-	// /[\s\S]/ means match anything... /./ doesn't match newlines
 	brush.push({
-		pattern: /<[^>]+>/g,
-		klass: 'tag',
-		allow: '*'
+		pattern: /<[^>\-\s]([^>'"!\/;\?@\[\]^`\{\}\|]|"[^"]*"|'[^']')*[\/?]?>/g,
+		brush: 'xml-tag'
 	});
 	
-	brush.push({
-		pattern: /<\/?((?:[^:\s>]+:)?)([^\s>]+)(\s[^>]*)?\/?>/g,
-		matches: Syntax.extractMatches({klass: 'namespace'}, {klass: 'tag-name'})
-	});
-	
-	brush.push({
-		pattern: /([^=\s]+)=(".*?"|'.*?'|[^\s>]+)/g,
-		matches: Syntax.extractMatches({klass: 'attribute', only: ['tag']}, {klass: 'string', only: ['tag']})
-	});
-	
-	brush.push({
-		pattern: /&\w+;/g,
-		klass: 'entity'
-	});
-	
-	brush.push({
-		pattern: /(%[0-9a-f]{2})/gi,
-		klass: 'percent-escape',
-		only: ['string']
-	});
-	
-	brush.push(Syntax.lib.singleQuotedString);
-	brush.push(Syntax.lib.doubleQuotedString);
+	brush.push(Syntax.lib.xmlEntity);
+	brush.push(Syntax.lib.xmlPercentEscape);
 	
 	brush.push(Syntax.lib.webLink);
 });
